************************************************************************************
***Table 1: formal vs. informal elites *********************************************
***Panels A and B: historical benefits *********************************************
************************************************************************************

clear
clear matrix
clear mata
set more off
set mem 256m
set sortseed 10000


*********************************
*1. Inputting data***************
*********************************

*** Subtreatment data ***
u "$codeddata/Baseline/coded_baseline_partV_hybrid", clear
gen in_out=(additionsubtreatment==0)
gen elite_sub=(tokohsubtreatment==1)

*** Merge ***
merge 1:1 hhid using "$codeddata/Baseline/elite_measures.dta"
keep if _merge==3
drop _merge
tempfile baseline
sa `baseline', replace

*** Other data ***
merge 1:1 hhid using "$codeddata/Baseline/allvar.dta"
assert _merge==3
drop _merge
merge 1:1 hhid using "$codeddata/Baseline/historical_getbenefit.dta"
assert _merge==3
drop _merge
merge 1:1 hhid using "$originaldata/new crosswalk.dta"
keep if _merge==1|_merge==3
drop _merge

*********************************
*2. Coding***********************
*********************************

*** Coding PPLS status ***
gen ppls08_1=(klas_ppls=="HM" | klas_ppls=="M" | klas_ppls=="SM")
gen ppls08_2=(klas_ppls=="M" | klas_ppls=="SM")
gen ppls08_3=(klas_ppls=="SM")
la var ppls08_1 "HM, M and SM"
la var ppls08_2 "M and SM"
la var ppls08_3 "SM"


*** Recoding elite measures ***
rename elite_self elite_related_4
rename elite_formal elite_related_5
rename elite_informal elite_related_6
rename elite_self_formal elite_related_7
rename elite_self_informal elite_related_8


*** Treatment status ***
gen PMT=(hybrid==0)






*********************************
*3. Analysis*********************
*********************************

forv x = 1/2 {
*Panel A: Formal elites
*Panel B: Informal elites
local i : word `x' of 5 6
local j : word `x' of A B

label var elite_related_`i' "Elite"

* Actual benefit receipt

areg getbenefit_BLT08 elite_related_`i' logconsumption , ab(kecagroup) cl(hhea)
qui summ getbenefit_BLT08 if e(sample)
local m0 = r(mean)
outreg2 using "$output/tables/Table 1`j'.doc", label keep(elite_related_`i') nor2 nocons word se bdec(3) addstat("Dependent Variable Mean",`m0') ctitle("BLT 08") replace

areg getbenefit_askeskin elite_related_`i' logconsumption , ab(kecagroup) cl(hhea)
qui summ getbenefit_askeskin if e(sample)
local m0 = r(mean)
outreg2 using "$output/tables/Table 1`j'.doc", label keep(elite_related_`i') nor2 nocons word se bdec(3) addstat("Dependent Variable Mean",`m0') ctitle("Jamkesmas") append

areg getbenefit_raskin elite_related_`i' logconsumption , ab(kecagroup) cl(hhea)
qui summ getbenefit_raskin if e(sample)
local m0 = r(mean)
outreg2 using "$output/tables/Table 1`j'.doc", label keep(elite_related_`i') nor2 nocons word se bdec(3) addstat("Dependent Variable Mean",`m0') ctitle("Raskin") append

 }
 


