************************************************************************************
***Table 1: formal vs. informal elites *********************************************
***Panels C and D: PKH Experiment **************************************************
************************************************************************************

clear
clear matrix
clear mata
set more off
set mem 256m
set sortseed 10000

*********************************
*1. Inputting data***************
*********************************

*** Actual beneficiaries ***
u "$originaldata/Endline2/hh_ad.dta", clear
keep hhid ad03
recode ad03 (3=0)
rename ad03 gotPKH
tempfile actual_bene
sa `actual_bene', replace

*** Subtreatment data ***
u "$codeddata/Baseline/coded_baseline_partV_hybrid", clear
gen in_out=(additionsubtreatment==0)
gen elite_sub=(tokohsubtreatment==1)

*** Merge ***
merge 1:1 hhid using "$codeddata/Baseline/elite_measures.dta"
keep if _merge==3
drop _merge
tempfile baseline
sa `baseline', replace

*** Other data ***
merge 1:1 hhid using "$codeddata/Baseline/allvar.dta"
assert _merge==3
drop _merge
merge 1:1 hhid using "$originaldata/new crosswalk.dta"
keep if _merge==1|_merge==3
drop _merge
merge 1:1 hhid using `actual_bene'
drop if _merge==2
drop _merge






*********************************
*2. Coding***********************
*********************************

*** Recoding elite measures ***
rename elite_self elite_related_4
rename elite_formal elite_related_5
rename elite_informal elite_related_6
rename elite_self_formal elite_related_7
rename elite_self_informal elite_related_8


*** Treatment status ***
gen PMT=(hybrid==0)


*** Interactions ***
g eliterel_elitesub_5 = elite_related_5*elite_sub
g eliterel_elitesub_6 = elite_related_6*elite_sub




*********************************
*3. Analysis*********************
*********************************

forv x = 1/2 {
*Panel C: Formal elites
*Panel D: Informal elites
local i : word `x' of 5 6
local j : word `x' of C D

label var elite_related_`i' "Elite"
label var eliterel_elitesub_`i' "Elite x Elite Subtreatment"

* Actual benefit receipt

areg gotPKH elite_related_`i' logconsumption  if PMT==1, ab(kecagroup) cl(hhea)
qui summ gotPKH if e(sample)
local m0 = r(mean)
outreg2 using "$output/tables/Table 1`j'.doc", label nocons nor2 keep(elite_related_`i') word se bdec(3) addstat("Dependent Variable Mean",`m0') ctitle("PMT") replace

areg gotPKH elite_related_`i' logconsumption if hybrid==1, ab(kecagroup) cl(hhea)
qui summ gotPKH if e(sample)
local m0 = r(mean)
outreg2 using "$output/tables/Table 1`j'.doc", label nocons nor2 keep(elite_related_`i') word se bdec(3) addstat("Dependent Variable Mean",`m0') ctitle("Community") append

areg gotPKH elite_related_`i' logconsumption elite_sub  eliterel_elitesub_`i' if hybrid==1, ab(kecagroup) cl(hhea)
qui summ gotPKH if e(sample)
local m0 = r(mean)
outreg2 using "$output/tables/Table 1`j'.doc", label nocons nor2 keep(elite_related_`i' eliterel_elitesub_`i') word se bdec(3) addstat("Dependent Variable Mean",`m0') ctitle("Community") append

* Test for difference between column 1 and column 2
qui {
cap g hycons = hybrid*logconsumption
g hyeli_`i' = hybrid*elite_related_`i'
cap egen interact = group(hybrid kecagroup)
areg gotPKH elite_related_`i' logconsumption hybrid hycons hyeli_`i', ab(interact) cl(hhea)
test _b[hybrid] = 0, notest
noi test _b[hyeli_`i'] = 0, accum
}
}

clear

