/* Predict PMT score of the SUSETI households */

clear
clear matrix
clear mata

set more off
set mem 256m

set sortseed 10000

** Set variables to use in regressions

local regressors "hhage_ssn asset_tbggas_ssn twall_ssn hhind_ssn hhserv_ssn dwater_ssn popdensity_pds asset_sepeda_ssn hhsma_ssn lighting_ssn credit_pds distance_pds toilet_ssn nchildsma_ssn nchildsd_ssn market_pds pcfloor_ssn hhinformal_ssn troof_ssn hhmalemarr_ssn hhmarried_ssn hhsize_ssn hhsize2_ssn hhmaxedsd_ssn hhmaxedsmp_ssn hhmaxedsma_ssn asset_mobilboat_ssn bidan_pds doctor_pds depratio_ssn hhsmp_ssn house_ssn road_pds posyandu_pds sd_pds smp_pds asset_motor_ssn nage04_ssn asset_kulkas_ssn tfloor_ssn hhagr_ssn hhsd_ssn polindes_pds hhmale_ssn nchildsmp_ssn puskesmas_pds hhage2_ssn micro_ssn"

**********************************
** Predict pmt score		**
**********************************;

use "$originaldata/Others/PODES/wgt_pds08_wide.dta"
rename kdprop prov

destring prov ur_desa,replace
gen kabu =100*prov+ur_desa

tempfile a
save `a'


use "$codeddata/Baseline/location.dta",clear
recode kec (998=.)
collapse (mean)  prov kab kec desa,by(hhea)
tostring prov kab kec desa,replace
count
sort hhea

tempfile b
save `b',replace


/* Merge all variables PMT variables from Baseline data */


use "$codeddata/Baseline/hhhead.dta", clear

merge 1:1 hhid using "$codeddata/Baseline/consumption.dta"
assert _merge==3
drop _merge
merge 1:1 hhid using "$codeddata/Baseline/hhcharacteristic.dta"
assert _merge==3
drop _merge
merge 1:1 hhid using "$codeddata/Baseline/hhasset.dta"
assert _merge==3
drop _merge
merge 1:1 hhid using "$codeddata/Baseline/hh_ar2.dta"
assert _merge==3
drop _merge

merge m:1 hhea using "$codeddata/Baseline/distance.dta"
assert _merge==3
drop _merge

merge m:1 hhea using `b'
assert _merge==3
drop _merge

destring prov kab kec desa,replace

tempfile c
save `c',replace 

use "$originaldata/Others/PODES/coding_podes08.dta"

destring prov kab kec desa,replace

merge 1:m prov kab kec desa using `c'

assert _merge==1|_merge==3
keep if _merge==3
drop _merge

tostring prov kab kec desa,replace
merge m:1 prov kab kec desa using "$codeddata/Others/Randomization/randomizationresults_111012_modified"	/*to get clas (urban or rural) variable */
assert _merge==3
drop _merge

gen pcfloor_ssn  = floorsize / hhsize
gen pcfloor2_ssn = pcfloor_ssn^2
label var pcfloor_ssn "Household floor area percentage"

rename distance distance_pds   /*match pds coefficient var name */
rename twall twall_ssn 		
rename dwater dwater_ssn
rename lighting lighting_ssn
rename toilet toilet_ssn
rename troof troof_ssn
rename house house_ssn
rename tfloor tfloor_ssn
rename asset_tbggas asset_tbggas_ssn
rename micro micro_ssn
rename age04 nage04_ssn 
rename eschild nchildsd_ssn
rename smpchild nchildsmp_ssn
rename sschild nchildsma_ssn
rename depratio depratio_ssn
rename hhmaxedsd hhmaxedsd_ssn
rename hhmaxedsmp hhmaxedsmp_ssn
rename hhmaxedsma hhmaxedsma_ssn
rename asset_sepeda asset_sepeda_ssn	
rename asset_mobilboat asset_mobilboat_ssn
rename asset_motor asset_motor_ssn
rename asset_kulkas asset_kulkas_ssn
rename hhsize hhsize_ssn
rename hhsize2 hhsize2_ssn
rename hhsector1 hhagr_ssn 		
rename hhsector2 hhind_ssn
rename hhsector3 hhserv_ssn
rename formal hhformal_ssn
rename informal hhinformal_ssn
rename hhsma hhsma_ssn
rename hhsmp hhsmp_ssn
rename hhsd hhsd_ssn
rename hhmalemarr hhmalemarr_ssn
rename hhmarried hhmarried_ssn
rename hhmale hhmale_ssn
rename hhage hhage_ssn
rename hhage2 hhage2_ssn

destring prov,replace
gen kabu = prov*100 + clas

merge m:1 kabu using `a'    
assert _merge==3
drop _merge

foreach x in `regressors' {
	gen comp_`x' = `x' * z_`x'
}

capture drop temp*
egen temp1 =rsum(comp_*)

gen PMTSCORE = temp1 + z_Constant

gen pcexppred = exp(PMTSCORE)


label var pcexppred "Per capita consumption from PMT (in Rp)"
label var PMTSCORE "Log Per capita consumption from PMT" 


bys hhea: egen rank_pmt = rank(pcexppred)
label var rank_pmt "Rank based on Per capita consumption from PMT within village"
bys hhea: gen nhhrank_pmt=_N
label var nhhrank_pmt "Number of household in village from PMT"

gen PMTRANK= rank_pmt/nhhrank_pmt
label var PMTRANK "Rank per capita consumption from PMT within village in percentiles"

compress
sort hhid
tostring prov kec kab desa,replace

save "$codeddata/Baseline/coding_suseti_pmt.dta", replace
