***************************************
** Match PMT and Hybrid baseline data for analysis
***************************************

******************************************************
******************************************************

clear
clear matrix
clear mata

set more off
set mem 256m

set sortseed 10000


***********************************For matched_baseline_hybrid******************************

*************
***For PMT***
*************

u "$originaldata/new crosswalk.dta", clear
keep if maintreatment==1

tempfile PMT
save `PMT',replace

/*get the total number of HH in PMT RTs*/
use "$originaldata/Baseline/k_data.dta",clear
keep hhid ea id01   /*id01 tells the total number of hhs in each RT */
rename ea hhea
rename id01 tothhinRT

drop if tothhinRT==.

tempfile c
save `c',replace

use "$codeddata/Others/randomization/randomizationresults_111012_modified",clear

merge 1:1 hhea using `c'
tab _merge
drop _merge

bysort maintreatment: egen totHH=sum (tothhinRT)
sum totHH if maintreatment==1		/*total number of households in the PMT RTs*/

/*Merge with baseline households*/
use "$codeddata/Baseline/coding_suseti_pmt",clear
keep hhid hhea prov kab kec desa r401c logconsumption consumption pcexppred PMTSCORE
order hhid hhea prov kab kec desa r401c logconsumption consumption pcexppred PMTSCORE
merge 1:1 hhid using `PMT'
assert _merge!=2
keep if _merge==3
drop _merge


tostring prov kab kec desa,replace
merge m:1 hhea using "$codeddata/Others/randomization/randomizationresults_111012_modified"
drop if _merge==2
drop _merge
	



tempfile matched_pmt
sa `matched_pmt', replace

****************
***For Hybrid***
****************
u "$originaldata/new crosswalk.dta", clear
keep if maintreatment==3

tempfile hybrid
sa `hybrid', replace

/*get the total number of HH in PMT RTs*/
use "$originaldata/Baseline/k_data.dta",clear
keep hhid ea id01   /*id01 tells the total number of hh in each RT */
rename ea hhea
rename id01 tothhinRT
drop if tothhinRT==.

tempfile c
save `c',replace

use "$codeddata/Others/randomization/randomizationresults_111012_modified",clear
merge 1:1 hhea using `c'
assert _merge==3
drop _merge

bysort maintreatment: egen totHH=sum (tothhinRT)
sum totHH if maintreatment==3		/*total number of households in the hybrid RTs*/

/*Merge with baseline households*/
use "$codeddata/Baseline/coding_suseti_pmt",clear
keep hhid hhea prov kab kec desa  r401c logconsumption consumption pcexppred PMTSCORE
order hhid hhea prov kab kec desa  r401c logconsumption consumption pcexppred PMTSCORE
merge 1:1 hhid using `hybrid'
drop if _merge==2 	/*only keep the baseline households*/
drop _merge

tostring prov kab kec desa,replace
merge m:1 hhea using "$codeddata/Others/randomization/randomizationresults_111012_modified"
assert _merge==3
drop _merge
	
keep if maintreatment==3	/*number of baseline households in hybrid RTs.*/
replace showup=0 if showup==.
replace getbenefit=0 if getbenefit==.
count if showup==1 	/*number of baseline hybrid households show up*/
count if getbenefit==1	/*number of baseline hybrid households get benefit.*/

append using `matched_pmt'

** Pov line jointly defined now -- 2/14/13
/*Let's define the poveryt line as the 16th percentile in the SUSETI
in per capita expenditrue in the baseline, by district. Let's define"very poor" as less than 0.8 * the poverty line. */
egen district=concat (prov kab)
replace district="1602" if district=="162"
replace district="1805" if district=="185"
bysort district: egen povertyline1=pctile(consumption),p(16)
gen verypoor_povertyline1=0
replace verypoor_povertyline1=1 if consumption<=0.8*povertyline1
count if verypoor_povertyline1==1
count if verypoor_povertyline1==1 & showup==1
count if verypoor_povertyline1==1 & getbenefit==1		

/*Conditional on being very poor. Using poverty lines defined in pmtscore.do*/
gen povertyline2=240315.5 if prov=="16"&clas==1
replace povertyline2=206641.8 if prov=="16"&clas==2
replace povertyline2=200971.1 if prov=="18"&clas==1
replace povertyline2=188815.4 if prov=="18"&clas==2
replace povertyline2=185687 if prov=="33"&clas==1
replace povertyline2=172602.8 if prov=="33"&clas==2
gen verypoor_povertyline2=0
replace verypoor_povertyline2=1 if consumption<=0.8*povertyline2

/*Conditional on being in the bottom 10% of each district.*/
bysort district: egen bottom10pct=pctile(consumption),p(10)
gen bottom10pct_d=0 
replace bottom10pct_d=1 if consumption<=bottom10pct
count if bottom10pct_d==1 & showup==1 	
count if bottom10pct_d==1 & getbenefit==1 	



/* Generate poverty density measure using PPLS08*/
destring prov kab kec desa,replace
tempfile baseline
save `baseline',replace

use "$originaldata/Others/PPLS08/r1602",clear
append using "$originaldata/Others/PPLS08/r1671" "$originaldata/Others/PPLS08/r1805" "$originaldata/Others/PPLS08/r1871" "$originaldata/Others/PPLS08/r3312" "$originaldata/Others/PPLS08/r3327"
gen poverty=0
replace poverty=1 if klas=="SM"|klas=="M"
collapse (sum) poverty, by (kdprop kdkabu kdkeca kdkelr)
rename kdprop prov
rename kdkabu kab
rename kdkeca kec
rename kdkelr desa
destring prov kab kec desa,replace

merge 1:m prov kab kec desa using `baseline'

tab _merge
keep if _merge==3
drop _merge

label var poverty "total number of hh in village marked as poor and very poor in PPLS08"
gen povertydensity=poverty/r401c
tostring prov kec kab desa,replace

//merge in baseline control variables (for regressional analysis)
//hh head education, # of household members, share in HH age 0-3,4-5,6-12,13-15, hh head gender, hh head widow.
merge 1:1 hhid using "$codeddata/Baseline/hhhead", keepusing(hhid educationhhhead hhmale hhwidow)
assert _merge!=1
keep if _merge==3
drop _merge
merge 1:1 hhid using "$codeddata/Baseline/consumption", keepusing(hhid hhsize)
assert _merge!=1
keep if _merge==3
drop _merge
merge 1:1 hhid using "$codeddata/Baseline/hh_ar2", keepusing(hhid children0to3 children4to5 children6to12 children13to15)
assert _merge!=1
keep if _merge==3
drop _merge
merge 1:1 hhid using "$originaldata/Baseline/hh_sw",keepusing (sw02)
keep if _merge==3
drop _merge
rename sw02 poor_self
recode poor_self (8=.)
merge 1:1 hhid using "$codeddata/Baseline/elite_related.dta"
keep if _merge==1 | _merge==3 /*Only keep master data*/
drop _merge
replace elite_related=0 if elite_related==.
merge 1:1 hhid using "$codeddata/Baseline/community_ranking.dta"
keep if _merge==1 | _merge==3 /*Only keep master data*/
drop _merge

save "$codeddata/Baseline/matched_baseline_hybrid.dta",replace

clear

